@@ -334,6 +334,8 @@ class TriggerSettings(util.DisableNewAttr):
         self._stream_mode = False
         self._support_get_duration = True
         self._is_pro = False
+        self._cached_samples = None
+        self._cached_offset = None
 
 
         self.disable_newattr()
@@ -434,10 +436,13 @@ class TriggerSettings(util.DisableNewAttr):
         Raises:
            ValueError: if number of samples is negative
         """
-        return self._get_num_samples()
+        if self._cached_samples is None:
+            self._cached_samples = self._get_num_samples()
+        return self._cached_samples
 
     @samples.setter
     def samples(self, samples):
+        self._cached_samples = samples
         self._set_num_samples(samples)
 
     @property
@@ -476,10 +481,13 @@ class TriggerSettings(util.DisableNewAttr):
         Raises:
            ValueError: if offset outside of range [0, 2**32)
         """
-        return self._get_offset()
+        if self._cached_offset is None:
+            self._cached_offset = self._get_offset()
+        return self._cached_offset
 
     @offset.setter
     def offset(self, setting):
+        self._cached_offset = setting
         self._set_offset(setting)
 
     @property
@@ -594,7 +602,7 @@ class TriggerSettings(util.DisableNewAttr):
         self._numSamples = samples
         self.oa.setNumSamples(samples)
 
-    def _get_num_samples(self, cached=False):
+    def _get_num_samples(self, cached=True):
         if self.oa is None:
             return 0
 
@@ -1469,6 +1477,7 @@ class ClockSettings(util.DisableNewAttr):
 
 class OpenADCInterface(object):
 
+    cached_settings = None
     def __init__(self, serial_instance):
         self.serial = serial_instance
         self.offset = 0.5
@@ -1523,7 +1532,7 @@ class OpenADCInterface(object):
 
             logging.error('%d errors in %d' % (totalerror, totalbytes))
 
-    def sendMessage(self, mode, address, payload=None, Validate=True, maxResp=None, readMask=None):
+    def sendMessage(self, mode, address, payload=None, Validate=False, maxResp=None, readMask=None):
         """Send a message out the serial port"""
 
         if payload is None:
@@ -1649,17 +1658,20 @@ class OpenADCInterface(object):
                         logging.error(errmsg)
 
 ### Generic
-    def setSettings(self, state, validate=True):
+    def setSettings(self, state, validate=False):
         cmd = bytearray(1)
         cmd[0] = state
+        self.cached_settings = state
         self.sendMessage(CODE_WRITE, ADDR_SETTINGS, cmd, Validate=validate)
 
-    def settings(self):
-        sets = self.sendMessage(CODE_READ, ADDR_SETTINGS)
-        if sets:
-            return sets[0]
-        else:
-            return 0
+    def settings(self, use_cached=False):
+        if (not use_cached) or (not self.cached_settings):
+            sets = self.sendMessage(CODE_READ, ADDR_SETTINGS)
+            if sets is None:
+                self.cached_settings = 0
+            else:
+                self.cached_settings = sets[0]
+        return self.cached_settings
 
     def setReset(self, value):
         if value:
@@ -1818,6 +1830,7 @@ class OpenADCInterface(object):
     #     return addr
 
     def arm(self, enable=True):
+        # keeps calling self.setting() - what if we cache it?
         if enable:
             #Must arm first
             self.setSettings(self.settings() | SETTINGS_ARM)
@@ -1896,22 +1909,24 @@ class OpenADCInterface(object):
 
             # NOTE: This doesn't actually delay until adc starts reading
             # so need to actually do the manual delay
-            nosampletimeout = self._nosampletimeout * 10
-            while (self.getBytesInFifo() == 0) and nosampletimeout:
-                logging.debug("Bytes in Fifo: {}".format(self.getBytesInFifo()))
-                time.sleep(0.001)
-                nosampletimeout -= 1
+            #nosampletimeout = self._nosampletimeout * 10
+            #while (self.getBytesInFifo() == 0) and nosampletimeout:
+            #    logging.debug("Bytes in Fifo: {}".format(self.getBytesInFifo()))
+            #    time.sleep(0.001)
+            #    nosampletimeout -= 1
 
-            if nosampletimeout == 0:
-                logging.warning('No samples received. Either very long offset, or no ADC clock (try "Reset ADC DCM"). '
-                                'If you need such a long offset, increase "scope.qtadc.sc._nosampletimeout" limit.')
-                timeout = True
+            #if nosampletimeout == 0:
+            #    logging.warning('No samples received. Either very long offset, or no ADC clock (try "Reset ADC DCM"). '
+            #                    'If you need such a long offset, increase "scope.qtadc.sc._nosampletimeout" limit.')
+            #    timeout = True
 
         # give time for ADC to finish reading data
         # may need to adjust delay
         cap_delay = (7.37E6 * 4 * samples) / (adc_freq * 24400)
         cap_delay *= 0.001
         time.sleep(cap_delay+sleeptime)
+        # 0.000819672131147541
+        # 
         #time.sleep(sleeptime) #need to do this one as well
         self.arm(False) # <------ ADC will stop reading after this
         return timeout
