@@ -39,7 +39,7 @@ from chipwhisperer.hardware.naeusb.naeusb import NAEUSB, packuint32, unpackuint3
 from chipwhisperer.hardware.naeusb.programmer_avr import AVRISP
 from chipwhisperer.hardware.naeusb.programmer_xmega import XMEGAPDI
 from chipwhisperer.hardware.naeusb.programmer_stm32fserial import STM32FSerial
-from chipwhisperer.common.utils.util import camel_case_deprecated
+from chipwhisperer.common.utils.util import camel_case_deprecated, DelayedKeyboardInterrupt
 import time
 import datetime
 
@@ -68,6 +68,7 @@ class ADCSettings(util.DisableNewAttr):
         return self.__repr__()
 
 
+
     @property
     def samples(self):
         """Number of samples to store."""
@@ -588,6 +589,10 @@ class CWNano(ScopeTemplate, util.DisableNewAttr):
     def _getNAEUSB(self):
         return self._cwusb
 
+    @property
+    def sn(self):
+        return self._cwusb.snum
+
     @property
     def latest_fw(self):
         from chipwhisperer.hardware.firmware.cwnano import fwver
@@ -618,48 +623,51 @@ class CWNano(ScopeTemplate, util.DisableNewAttr):
 
     def _dis(self):
         self.enable_newattr()
+        self.usbdev().close()
         self._is_connected = False
         return True
 
     def arm(self):
         """Arm the ADC, the trigger will be GPIO4 rising edge (fixed trigger)."""
-        if self.connectStatus is False:
-            raise Warning("Scope \"" + self.getName() + "\" is not connected. Connect it first...")
+        with DelayedKeyboardInterrupt():
+            if self.connectStatus is False:
+                raise Warning("Scope \"" + self.getName() + "\" is not connected. Connect it first...")
 
-        self._cwusb.sendCtrl(self.REQ_ARM, 1)
+            self._cwusb.sendCtrl(self.REQ_ARM, 1)
 
 
     def capture(self):
         """Raises IOError if unknown failure, returns 'True' if timeout, 'False' if no timeout"""
 
-        starttime = datetime.datetime.now()
-        while self._cwusb.readCtrl(self.REQ_ARM, dlen=1)[0] == 0:
-            # Wait for a moment before re-running the loop
-            time.sleep(0.05)
-            diff = datetime.datetime.now() - starttime
+        with DelayedKeyboardInterrupt():
+            starttime = datetime.datetime.now()
+            while self._cwusb.readCtrl(self.REQ_ARM, dlen=1)[0] == 0:
+                # Wait for a moment before re-running the loop
+                time.sleep(0.001)
+                diff = datetime.datetime.now() - starttime
 
-            # If we've timed out, don't wait any longer for a trigger
-            if (diff.total_seconds() > self._timeout):
-                logging.warning('Timeout in cwnano capture()')
-                return True
-
-        self._lasttrace = self._cwusb.cmdReadMem(0, self.adc.samples)
-
-        # can just keep rerunning this until it works I think
-        i = 0
-        while len(self._lasttrace) < self.adc.samples:
-            logging.debug("couldn't read ADC data from Nano, retrying...")
+                # If we've timed out, don't wait any longer for a trigger
+                if (diff.total_seconds() > self._timeout):
+                    logging.warning('Timeout in cwnano capture()')
+                    return True
 
             self._lasttrace = self._cwusb.cmdReadMem(0, self.adc.samples)
-            i+= 1
-            if i > 20:
-                logging.warning("Couldn't read trace data back from Nano")
-                return True
-        self._lasttrace = np.array(self._lasttrace) / 256.0 - 0.5
 
-        #self.newDataReceived(0, self._lasttrace, 0, self.adc.clk_freq)
+            # can just keep rerunning this until it works I think
+            i = 0
+            while len(self._lasttrace) < self.adc.samples:
+                logging.debug("couldn't read ADC data from Nano, retrying...")
 
-        return False
+                self._lasttrace = self._cwusb.cmdReadMem(0, self.adc.samples)
+                i+= 1
+                if i > 20:
+                    logging.warning("Couldn't read trace data back from Nano")
+                    return True
+            self._lasttrace = np.array(self._lasttrace) / 256.0 - 0.5
+
+            #self.newDataReceived(0, self._lasttrace, 0, self.adc.clk_freq)
+
+            return False
 
 
     def get_last_trace(self):
