@@ -56,6 +56,8 @@ class SimpleSerial(TargetTemplate, util.DisableNewAttr):
       * :attr:`target.baud <.SimpleSerial.baud>`
       * :meth:`target.write <.SimpleSerial.write>`
       * :meth:`target.read <.SimpleSerial.read>`
+      * :meth:`target.in_waiting <.SimpleSerial.in_waiting>`
+      * :meth:`target.in_waiting_tx <.SimpleSerial.in_waiting_tx>`
       * :meth:`target.simpleserial_wait_ack <.SimpleSerial.simpleserial_wait_ack>`
       * :meth:`target.simpleserial_write <.SimpleSerial.simpleserial_write>`
       * :meth:`target.simpleserial_read <.SimpleSerial.simpleserial_read>`
@@ -68,7 +70,7 @@ class SimpleSerial(TargetTemplate, util.DisableNewAttr):
         The CWLite, CW1200, and CWNano have a 128 byte read buffer and a 128 
         byte send buffer. If the read buffer overflows, a warning message
         will be printed. Prior to firmware 0.20, the send buffer can silently
-        overflow.
+        overflow. In ChipWhisperer 5.4, this is upgraded to a 200 byte read/send buffer.
     """
     _name = "Simple Serial"
 
