@@ -58,6 +58,7 @@ class USART(object):
         # but this obj gets created a lot,
         # and don't want to spam them
         self.tx_buf_in_wait = False
+        self.fw_read = None
 
     def init(self, baud=115200, stopbits=1, parity="none"):
         """
@@ -133,8 +134,7 @@ class USART(object):
             # Can probably elimiate some USB communication
             # to make this faster, but okay for now...
             if self.tx_buf_in_wait:
-                while (datatosend + self.in_waiting_tx()) > 128:
-                    pass
+                datatosend = min(datatosend, 128-self.in_waiting_tx())
             self._usb.sendCtrl(self.CMD_USART0_DATA, 0, data[datasent:(datasent + datatosend)])
             datasent += datatosend
 
@@ -209,5 +209,6 @@ class USART(object):
 
     @property
     def fw_version(self):
-        a = self._usb.readFwVersion()
-        return {"major": a[0], "minor": a[1], "debug": a[2]}
+        if not self.fw_read:
+            self.fw_read = self._usb.readFwVersion()
+        return {"major": self.fw_read[0], "minor": self.fw_read[1], "debug": self.fw_read[2]}
